This data directory contains csv files for looking up user friendly terms from web request results.

zobler_540_MixS_lookup -- Contains mapping for soil types

ENVO_Landuse_Systems_lookup -- Contains mappings for the different landuse classification systems

ENVO_Landuse_lookup -- Contains mappings for the landuse terms to ENVO ontology